@@ -1,62 +1,22 @@
 import pandas as pd
-import numpy as np
 import plotly.graph_objects as go
 import plotly as pl
 import base64
 from commodutil import transforms
 from commodutil import dates
-default_line_col = 'khaki'
+
 
 # margin to use in HTML charts - make charts bigger but leave space for title
 narrow_margin = {'l':2, 'r':2, 't':30, 'b':10}
 
-# try to put deeper colours for recent years, lighter colours for older years
-year_col_map = {
-    -10: 'wheat',
-    -9: 'burlywood',
-    -8: 'steelblue',
-    -7: 'aquamarine',
-    -6: 'orange',
-    -5: 'yellow',
-    -4: 'saddlebrown',
-    -3: 'mediumblue',
-    -2: 'darkgreen',
-    -1: 'coral',
-    0: 'black',
-    1: 'red',
-    2: 'firebrick',
-    3: 'darkred',
-    4: 'crimson',
-}
 
+def gen_title(df, **kwargs):
+    title = kwargs.get('title', '')
+    inc_change_sum = kwargs.get('inc_change_sum', True)
+    if inc_change_sum:
+        title = '{}   {}'.format(title, delta_summary_str(df))
 
-def get_year_line_delta(year):
-    if isinstance(year, str):
-        year = int(year)
-
-    delta = year - dates.curyear
-    return delta
-
-
-def get_year_line_col(year):
-    """
-    Given a year, calculate a consistent line colour across charts
-    """
-    delta = get_year_line_delta(year)
-    return year_col_map.get(delta, default_line_col)
-
-
-def get_year_line_width(year):
-    delta = get_year_line_delta(year)
-    if delta == 0:
-        return 3
-
-    return 2
-
-
-def line_visible(year):
-    delta = get_year_line_delta(year)
-    return None if delta >= -5 else "legendonly"
+    return title
 
 
 def seas_table(hist, fwd=None):
@@ -88,26 +48,6 @@ def seas_table(hist, fwd=None):
     return df
 
 
-def std_yr_col(df, asdict=False):
-    """
-    Given a dataframe with yearly columns, determine the line colour to use
-    """
-
-    if isinstance(df, pd.Series):
-        df = pd.DataFrame(df)
-
-    yearmap = dates.find_year(df, use_delta=True)
-    colmap = {}
-    for colname, delta in yearmap.items():
-        colmap[colname] = year_col_map.get(delta, default_line_col)
-
-    if asdict:
-        return colmap
-
-    # return array of colours to use - this can be passed into cufflift iplot method
-    return [colmap[x] for x in df]
-
-
 def delta_summary_str(df):
     """
     Given a timeseries, produce a string which shows the latest change
@@ -126,43 +66,6 @@ def delta_summary_str(df):
     return s
 
 
-def min_max_range(seas, shaded_range):
-    """
-    Calculate min and max for seas
-    If an int eg 5, then do curyear -1 and curyear -6
-    If list then do the years in that list eg 2012-2019
-    :param seas:
-    :param shaded_range:
-    :return:
-    """
-    seas = seas.dropna(how='all', axis=1)
-    seasf = seas.rename(columns=dates.find_year(seas))
-
-    # only consider when we have full(er) data for a given range
-    fulldata = pd.DataFrame(seasf.isna().sum()) # count non-na values
-    if not (fulldata == 0).all().iloc[0]: # line below doesn't apple when we have full data for all columns
-        fulldata = fulldata[fulldata.apply(lambda x: np.abs(x - x.mean()) / x.std() < 1.5).all(axis=1)] # filter columns with high emtply values
-    seasf = seasf[fulldata.index] # use these column names only
-
-    if isinstance(shaded_range, int):
-        end_year = dates.curyear - 1
-        start_year = end_year - (shaded_range - 1)
-    else:
-        start_year, end_year = shaded_range[0], shaded_range[1]
-
-    r = seasf[[x for x in seasf.columns if x >= start_year and x <= end_year]]
-    res = r.copy()
-    res['min'] = res.min(1)
-    res['max'] = res.max(1)
-    res = res[['min', 'max']]
-
-    if len(r.columns) >= 2:
-        rangeyr = int(len(r.columns)) # end_year - start_year
-    else:
-        rangeyr = None
-    return res, rangeyr
-
-
 def format_date_col(col, date_format='%d-%b'):
     """
     Format a column heading as a data
@@ -215,6 +118,14 @@ def reindex_year_df_rel_col(df):
     return res_col
 
 
+def infer_freq(df):
+    histfreq = 'D' # sometimes infer_freq returns null - assume mostly will be a daily series
+    if df is not None:
+        histfreq = pd.infer_freq(df.index)
+
+    return histfreq
+
+
 def plhtml(fig, margin=narrow_margin, **kwargs):
     """
     Given a plotly figure, return it as a div
